]> AND Private Git Repository - loba.git/blobdiff - options.h
Logo AND Algorithmique Numérique Distribuée

Private GIT Repository
Add min and max values in statistics.
[loba.git] / options.h
index 0c69e116f75528bde066e4bbe3455ac92e0224de..ef7a73e6ce379d9915ee7e213a59db267487a4cd 100644 (file)
--- a/options.h
+++ b/options.h
@@ -20,7 +20,8 @@ namespace opt {
     extern std::string program_name;
     extern int help_requested;
     extern bool version_requested;
     extern std::string program_name;
     extern int help_requested;
     extern bool version_requested;
-    extern int option_x;       // hidden option, for debugging purpose
+    extern int option_x;       // hidden option (int), for testing
+    extern double option_X;    // hidden option (double), for testing
 
     // Simulation parameters
     extern int log_rate;
 
     // Simulation parameters
     extern int log_rate;
@@ -43,9 +44,12 @@ namespace opt {
     // Load balancing algorithm
     extern std::string loba_algo;
     extern bool bookkeeping;
     // Load balancing algorithm
     extern std::string loba_algo;
     extern bool bookkeeping;
+    extern bool egocentric;
     extern double min_transfer_amount;
     extern double max_transfer_amount;
     extern double min_lb_iter_duration;
     extern double min_transfer_amount;
     extern double max_transfer_amount;
     extern double min_lb_iter_duration;
+    extern bool integer_transfer;
+    extern unsigned loba_best_divisor;
 
     // Application parameters
     extern cost_func comp_cost;
 
     // Application parameters
     extern cost_func comp_cost;